<!--
SPDX-FileCopyrightText: Copyright 2024-2025 Arm Limited and/or its affiliates <open-source-office@arm.com>

SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the License); you may
not use this file except in compliance with the License.
You may obtain a copy of the License at

www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an AS IS BASIS, WITHOUT
WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->
# Third Party Software

The following lists the Third Party software versions and licenses used by Vela:
* FlatBuffers [v24.12.23](https://github.com/google/flatbuffers/releases/tag/v24.12.23) -
  ([Apache-2.0 License](https://github.com/google/flatbuffers/blob/v24.12.23/LICENSE))

* fmt [11.1.1](https://github.com/fmtlib/fmt/releases/tag/11.1.1) -
  ([MIT License](https://github.com/fmtlib/fmt/blob/11.1.1/LICENSE))

* Catch2 [v3.8.0](https://github.com/catchorg/Catch2/releases/tag/v3.8.0) -
  ([BSL-1.0 License](https://github.com/catchorg/Catch2/blob/v3.8.0/LICENSE.txt))

* Gemmlowp [09d81e02ab15b41405caebeb5eb63fd12555aee3](https://github.com/google/gemmlowp/tree/09d81e02ab15b41405caebeb5eb63fd12555aee3) -
  ([Apache-2.0 License](https://github.com/google/gemmlowp/blob/09d81e02ab15b41405caebeb5eb63fd12555aee3/LICENSE))

* pybind11 [v2.13.6](https://github.com/pybind/pybind11/releases/tag/v2.13.6) -
  ([BSD-3-Clause License](https://github.com/pybind/pybind11/blob/v2.13.6/LICENSE))